aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJesse McGuire <jessemcguire@google.com>2022-05-16 14:44:12 -0700
committerChromeos LUCI <chromeos-scoped@luci-project-accounts.iam.gserviceaccount.com>2022-05-17 06:03:15 +0000
commit92aaa4900ef97b8d4be0ecf0406b3ec7ae496116 (patch)
tree858e4dab74bd28b87d07186cbd58af2fcc985f39
parent4248f620ac28b75a174d299f48b8768d06f4993b (diff)
downloadautotest-92aaa4900ef97b8d4be0ecf0406b3ec7ae496116.tar.gz
autotest: server brand unification
Update 'Chrome OS' -> 'ChromeOS' BUG=b:231760315 TEST=unittest; cq Change-Id: I601e985199046c64f2713bd4223a4d5bc96543c8 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/third_party/autotest/+/3649259 Reviewed-by: Derek Beckett <dbeckett@chromium.org> Auto-Submit: Jesse McGuire <jessemcguire@google.com> Tested-by: Jesse McGuire <jessemcguire@google.com> Commit-Queue: Derek Beckett <dbeckett@chromium.org>
-rw-r--r--server/afe_utils.py4
-rw-r--r--server/frontend.py10
-rw-r--r--server/hosts/base_servohost.py4
-rw-r--r--server/hosts/cros_firmware.py2
-rw-r--r--server/hosts/cros_host.py10
-rw-r--r--server/hosts/rpc_server_tracker.py2
-rw-r--r--server/hosts/servo_repair.py4
-rw-r--r--server/hosts/teststation_host.py2
-rw-r--r--server/hosts/tls_client/autotest_common.proto6
-rw-r--r--server/hosts/tls_client/autotest_common_pb2_grpc.py200
-rw-r--r--server/sequence.py2
11 files changed, 123 insertions, 123 deletions
diff --git a/server/frontend.py b/server/frontend.py
index 71f661ffad..90915c88a8 100644
--- a/server/frontend.py
+++ b/server/frontend.py
@@ -301,9 +301,9 @@ def format_cros_image_name(board, version):
class _CrosVersionMap(_OSVersionMap):
"""
- Stable version mapping for Chrome OS release images.
+ Stable version mapping for ChromeOS release images.
- This class manages a mapping of Chrome OS board names to known-good
+ This class manages a mapping of ChromeOS board names to known-good
release (or canary) images. The images selected can be installed on
DUTs during repair tasks, as a way of getting a DUT into a known
working state.
@@ -397,9 +397,9 @@ class _FAFTVersionMap(_SuffixHackVersionMap):
class _FirmwareVersionMap(_SuffixHackVersionMap):
"""
- Stable version mapping for firmware supplied in Chrome OS images.
+ Stable version mapping for firmware supplied in ChromeOS images.
- A Chrome OS image bundles a version of the firmware that the
+ A ChromeOS image bundles a version of the firmware that the
device should update to when the OS version is installed during
AU.
@@ -427,7 +427,7 @@ class _FirmwareVersionMap(_SuffixHackVersionMap):
class AFE(RpcClient):
# Known image types for stable version mapping objects.
- # CROS_IMAGE_TYPE - Mappings for Chrome OS images.
+ # CROS_IMAGE_TYPE - Mappings for ChromeOS images.
# FAFT_IMAGE_TYPE - Mappings for Firmware images for FAFT repair.
# FIRMWARE_IMAGE_TYPE - Mappings for released RW Firmware images.
#
diff --git a/server/hosts/base_servohost.py b/server/hosts/base_servohost.py
index 7aab705084..247587ab01 100644
--- a/server/hosts/base_servohost.py
+++ b/server/hosts/base_servohost.py
@@ -295,12 +295,12 @@ class BaseServoHost(ssh_host.SSHHost):
"""Update the image on the servo host, if needed.
This method recognizes the following cases:
- * If the Host is not running Chrome OS, do nothing.
+ * If the Host is not running ChromeOS, do nothing.
* If a previously triggered update is now complete, reboot
to the new version.
* If the host is processing an update do nothing.
* If the host has an update that pending on reboot, do nothing.
- * If the host is running a version of Chrome OS different
+ * If the host is running a version of ChromeOS different
from the default for servo Hosts, start an update.
@stable_version the target build number.(e.g. R82-12900.0.0)
diff --git a/server/hosts/cros_firmware.py b/server/hosts/cros_firmware.py
index a9807f54e6..6571ca3b69 100644
--- a/server/hosts/cros_firmware.py
+++ b/server/hosts/cros_firmware.py
@@ -7,7 +7,7 @@
Repair actions and verifiers relating to CrOS firmware.
This contains the repair actions and verifiers need to find problems
-with the firmware installed on Chrome OS DUTs, and when necessary, to
+with the firmware installed on ChromeOS DUTs, and when necessary, to
fix problems by updating or re-installing the firmware.
The operations in the module support two distinct use cases:
diff --git a/server/hosts/cros_host.py b/server/hosts/cros_host.py
index e91c660745..685ae791c4 100644
--- a/server/hosts/cros_host.py
+++ b/server/hosts/cros_host.py
@@ -74,7 +74,7 @@ class CrosHost(abstract_ssh.AbstractSSHHost):
_AFE = frontend_wrappers.RetryingAFE(timeout_min=5, delay_sec=10)
- # Timeout values (in seconds) associated with various Chrome OS
+ # Timeout values (in seconds) associated with various ChromeOS
# state changes.
#
# In general, a good rule of thumb is that the timeout can be up
@@ -1851,7 +1851,7 @@ class CrosHost(abstract_ssh.AbstractSSHHost):
"""
This function reboots the site host. The more generic
RemoteHost.reboot() performs sync and sleeps for 5
- seconds. This is not necessary for Chrome OS devices as the
+ seconds. This is not necessary for ChromeOS devices as the
sync should be finished in a short time during the reboot
command.
"""
@@ -1999,7 +1999,7 @@ class CrosHost(abstract_ssh.AbstractSSHHost):
return True
def verify_software(self):
- """Verify working software on a Chrome OS system.
+ """Verify working software on a ChromeOS system.
Tests for the following conditions:
1. All conditions tested by the parent version of this
@@ -2059,7 +2059,7 @@ class CrosHost(abstract_ssh.AbstractSSHHost):
def verify(self):
- """Verify Chrome OS system is in good state."""
+ """Verify ChromeOS system is in good state."""
message = 'Beginning verify for host %s board %s model %s'
info = self.host_info_store.get()
message %= (self.hostname, info.board, info.model)
@@ -2082,7 +2082,7 @@ class CrosHost(abstract_ssh.AbstractSSHHost):
alive_interval=None,
alive_count_max=None,
connection_attempts=None):
- """Override default make_ssh_command to use options tuned for Chrome OS.
+ """Override default make_ssh_command to use options tuned for ChromeOS.
Tuning changes:
- ConnectTimeout=30; maximum of 30 seconds allowed for an SSH
diff --git a/server/hosts/rpc_server_tracker.py b/server/hosts/rpc_server_tracker.py
index a607e0345f..d001e86cfb 100644
--- a/server/hosts/rpc_server_tracker.py
+++ b/server/hosts/rpc_server_tracker.py
@@ -41,7 +41,7 @@ class RpcServerTracker(object):
def _setup_port(self, port, command_name, remote_pid=None):
"""Sets up a tunnel process and register it to rpc_server_tracker.
- Chrome OS on the target closes down most external ports for security.
+ ChromeOS on the target closes down most external ports for security.
We could open the port, but doing that would conflict with security
tests that check that only expected ports are open. So, to get to
the port on the target we use an ssh tunnel.
diff --git a/server/hosts/servo_repair.py b/server/hosts/servo_repair.py
index 9f869f0ba7..1da6c8b90d 100644
--- a/server/hosts/servo_repair.py
+++ b/server/hosts/servo_repair.py
@@ -1100,7 +1100,7 @@ class _RestartServod(hosts.RepairAction):
elif not host.is_cros_host():
raise hosts.AutoservRepairError(
'Can\'t restart servod: not running '
- 'embedded Chrome OS.',
+ 'embedded ChromeOS.',
'servo_not_applicable_to_non_cros_host')
host.restart_servod()
@@ -1410,7 +1410,7 @@ class _ServoMicroFlashRepair(hosts.RepairAction):
if not host.is_cros_host():
raise hosts.AutoservRepairError(
'Can\'t restart servod: not running '
- 'embedded Chrome OS.',
+ 'embedded ChromeOS.',
'servo_not_applicable_to_non_cros_host')
servo = host.get_servo()
if not servo or self._TARGET_SERVO not in servo.get_servo_type():
diff --git a/server/hosts/teststation_host.py b/server/hosts/teststation_host.py
index e2fac55433..79d3dd3670 100644
--- a/server/hosts/teststation_host.py
+++ b/server/hosts/teststation_host.py
@@ -128,7 +128,7 @@ class TestStationHost(base_classes.Host):
ignore_timeout is True.
"""
# TODO (sbasi/kevcheng) - Make teststation_host check if running
- # on Chrome OS, rather than MobLab when prepending sudo to fastboot.
+ # on ChromeOS, rather than MobLab when prepending sudo to fastboot.
if cmd.startswith('fastboot ') and self.is_moblab:
cmd = 'sudo -n ' + cmd
if force_tty:
diff --git a/server/hosts/tls_client/autotest_common.proto b/server/hosts/tls_client/autotest_common.proto
index 45242b5eb3..6b842cc060 100644
--- a/server/hosts/tls_client/autotest_common.proto
+++ b/server/hosts/tls_client/autotest_common.proto
@@ -48,10 +48,10 @@ service Common {
rpc ExecDutCommand(ExecDutCommandRequest)
returns (stream ExecDutCommandResponse);
- // ProvisionDut installs a specified version of Chrome OS on the DUT, along
+ // ProvisionDut installs a specified version of ChromeOS on the DUT, along
// with any specified DLCs.
//
- // If the DUT is already on the specified version of Chrome OS, the OS will
+ // If the DUT is already on the specified version of ChromeOS, the OS will
// not be provisioned.
//
// If the DUT already has the specified list of DLCs, only the missing DLCs
@@ -186,7 +186,7 @@ message ProvisionDutRequest {
string gs_path_prefix = 1;
}
}
- // image specifies the Chrome OS image with which to provision the DUT.
+ // image specifies the ChromeOS image with which to provision the DUT.
ChromeOSImage image = 2;
// Reference DLCs developer documentation:
diff --git a/server/hosts/tls_client/autotest_common_pb2_grpc.py b/server/hosts/tls_client/autotest_common_pb2_grpc.py
index 6804124f06..5bac36ae84 100644
--- a/server/hosts/tls_client/autotest_common_pb2_grpc.py
+++ b/server/hosts/tls_client/autotest_common_pb2_grpc.py
@@ -7,7 +7,7 @@ from autotest_lib.server.hosts.tls_client import autotest_common_pb2 as autotest
from autotest_lib.server.hosts.tls_client.dependencies.longrunning import operations_pb2 as dependencies_dot_longrunning_dot_operations__pb2
class CommonStub(object):
- """Common lab services implemented on top of the wiring APIs.
+ """Common lab services implemented on top of the wiring APIs.
The key words "MUST", "MUST NOT", "REQUIRED", "SHALL", "SHALL
NOT", "SHOULD", "SHOULD NOT", "RECOMMENDED", "MAY", and
@@ -20,46 +20,46 @@ class CommonStub(object):
they can be fixed.
"""
- def __init__(self, channel):
- """Constructor.
+ def __init__(self, channel):
+ """Constructor.
Args:
channel: A grpc.Channel.
"""
- self.ExecDutCommand = channel.unary_stream(
- '/chromiumos.config.api.test.tls.Common/ExecDutCommand',
- request_serializer=autotest__common__pb2.ExecDutCommandRequest.SerializeToString,
- response_deserializer=autotest__common__pb2.ExecDutCommandResponse.FromString,
- )
- self.ProvisionDut = channel.unary_unary(
- '/chromiumos.config.api.test.tls.Common/ProvisionDut',
- request_serializer=autotest__common__pb2.ProvisionDutRequest.SerializeToString,
- response_deserializer=dependencies_dot_longrunning_dot_operations__pb2.Operation.FromString,
- )
- self.ProvisionLacros = channel.unary_unary(
- '/chromiumos.config.api.test.tls.Common/ProvisionLacros',
- request_serializer=autotest__common__pb2.ProvisionLacrosRequest.SerializeToString,
- response_deserializer=dependencies_dot_longrunning_dot_operations__pb2.Operation.FromString,
- )
- self.FetchCrashes = channel.unary_stream(
- '/chromiumos.config.api.test.tls.Common/FetchCrashes',
- request_serializer=autotest__common__pb2.FetchCrashesRequest.SerializeToString,
- response_deserializer=autotest__common__pb2.FetchCrashesResponse.FromString,
- )
- self.CreateFakeOmaha = channel.unary_unary(
- '/chromiumos.config.api.test.tls.Common/CreateFakeOmaha',
- request_serializer=autotest__common__pb2.CreateFakeOmahaRequest.SerializeToString,
- response_deserializer=autotest__common__pb2.FakeOmaha.FromString,
- )
- self.DeleteFakeOmaha = channel.unary_unary(
- '/chromiumos.config.api.test.tls.Common/DeleteFakeOmaha',
- request_serializer=autotest__common__pb2.DeleteFakeOmahaRequest.SerializeToString,
- response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
- )
+ self.ExecDutCommand = channel.unary_stream(
+ '/chromiumos.config.api.test.tls.Common/ExecDutCommand',
+ request_serializer=autotest__common__pb2.ExecDutCommandRequest.SerializeToString,
+ response_deserializer=autotest__common__pb2.ExecDutCommandResponse.FromString,
+ )
+ self.ProvisionDut = channel.unary_unary(
+ '/chromiumos.config.api.test.tls.Common/ProvisionDut',
+ request_serializer=autotest__common__pb2.ProvisionDutRequest.SerializeToString,
+ response_deserializer=dependencies_dot_longrunning_dot_operations__pb2.Operation.FromString,
+ )
+ self.ProvisionLacros = channel.unary_unary(
+ '/chromiumos.config.api.test.tls.Common/ProvisionLacros',
+ request_serializer=autotest__common__pb2.ProvisionLacrosRequest.SerializeToString,
+ response_deserializer=dependencies_dot_longrunning_dot_operations__pb2.Operation.FromString,
+ )
+ self.FetchCrashes = channel.unary_stream(
+ '/chromiumos.config.api.test.tls.Common/FetchCrashes',
+ request_serializer=autotest__common__pb2.FetchCrashesRequest.SerializeToString,
+ response_deserializer=autotest__common__pb2.FetchCrashesResponse.FromString,
+ )
+ self.CreateFakeOmaha = channel.unary_unary(
+ '/chromiumos.config.api.test.tls.Common/CreateFakeOmaha',
+ request_serializer=autotest__common__pb2.CreateFakeOmahaRequest.SerializeToString,
+ response_deserializer=autotest__common__pb2.FakeOmaha.FromString,
+ )
+ self.DeleteFakeOmaha = channel.unary_unary(
+ '/chromiumos.config.api.test.tls.Common/DeleteFakeOmaha',
+ request_serializer=autotest__common__pb2.DeleteFakeOmahaRequest.SerializeToString,
+ response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
+ )
class CommonServicer(object):
- """Common lab services implemented on top of the wiring APIs.
+ """Common lab services implemented on top of the wiring APIs.
The key words "MUST", "MUST NOT", "REQUIRED", "SHALL", "SHALL
NOT", "SHOULD", "SHOULD NOT", "RECOMMENDED", "MAY", and
@@ -72,8 +72,8 @@ class CommonServicer(object):
they can be fixed.
"""
- def ExecDutCommand(self, request, context):
- """ExecDutCommand runs a command on a DUT.
+ def ExecDutCommand(self, request, context):
+ """ExecDutCommand runs a command on a DUT.
The working directory is /.
A tty is not spawned for the command.
@@ -95,36 +95,36 @@ class CommonServicer(object):
If the stream is interrupted, the implementation MAY attempt to
stop the command by sending SIGINT, SIGHUP, SIGTERM, or SIGKILL.
"""
- context.set_code(grpc.StatusCode.UNIMPLEMENTED)
- context.set_details('Method not implemented!')
- raise NotImplementedError('Method not implemented!')
+ context.set_code(grpc.StatusCode.UNIMPLEMENTED)
+ context.set_details('Method not implemented!')
+ raise NotImplementedError('Method not implemented!')
- def ProvisionDut(self, request, context):
- """ProvisionDut installs a specified version of Chrome OS on the DUT, along
+ def ProvisionDut(self, request, context):
+ """ProvisionDut installs a specified version of ChromeOS on the DUT, along
with any specified DLCs.
- If the DUT is already on the specified version of Chrome OS, the OS will
+ If the DUT is already on the specified version of ChromeOS, the OS will
not be provisioned.
If the DUT already has the specified list of DLCs, only the missing DLCs
will be provisioned.
"""
- context.set_code(grpc.StatusCode.UNIMPLEMENTED)
- context.set_details('Method not implemented!')
- raise NotImplementedError('Method not implemented!')
+ context.set_code(grpc.StatusCode.UNIMPLEMENTED)
+ context.set_details('Method not implemented!')
+ raise NotImplementedError('Method not implemented!')
- def ProvisionLacros(self, request, context):
- """ProvisionLacros installs a specified version of Lacros on the DUT.
+ def ProvisionLacros(self, request, context):
+ """ProvisionLacros installs a specified version of Lacros on the DUT.
If the DUT already has the specified version of Lacros, Lacros will not be
provisioned.
"""
- context.set_code(grpc.StatusCode.UNIMPLEMENTED)
- context.set_details('Method not implemented!')
- raise NotImplementedError('Method not implemented!')
+ context.set_code(grpc.StatusCode.UNIMPLEMENTED)
+ context.set_details('Method not implemented!')
+ raise NotImplementedError('Method not implemented!')
- def FetchCrashes(self, request, context):
- """FetchCrashes gets a stream of all crash reports currently on the DUT.
+ def FetchCrashes(self, request, context):
+ """FetchCrashes gets a stream of all crash reports currently on the DUT.
The stream returned may split up a crash over multiple
`FetchCrashesResponse` protos. See the definition of that proto for
@@ -132,60 +132,60 @@ class CommonServicer(object):
This call is read-only: it doesn't delete the crashes that it reads.
"""
- context.set_code(grpc.StatusCode.UNIMPLEMENTED)
- context.set_details('Method not implemented!')
- raise NotImplementedError('Method not implemented!')
+ context.set_code(grpc.StatusCode.UNIMPLEMENTED)
+ context.set_details('Method not implemented!')
+ raise NotImplementedError('Method not implemented!')
- def CreateFakeOmaha(self, request, context):
- """CreateFakeOmaha starts a fake Omaha service on TLS and exposes the
+ def CreateFakeOmaha(self, request, context):
+ """CreateFakeOmaha starts a fake Omaha service on TLS and exposes the
listened port to the DUT.
"""
- context.set_code(grpc.StatusCode.UNIMPLEMENTED)
- context.set_details('Method not implemented!')
- raise NotImplementedError('Method not implemented!')
+ context.set_code(grpc.StatusCode.UNIMPLEMENTED)
+ context.set_details('Method not implemented!')
+ raise NotImplementedError('Method not implemented!')
- def DeleteFakeOmaha(self, request, context):
- """DeleteFakeOmaha deletes the specified fake Omaha resource created by
+ def DeleteFakeOmaha(self, request, context):
+ """DeleteFakeOmaha deletes the specified fake Omaha resource created by
CreateFakeOmaha.
"""
- context.set_code(grpc.StatusCode.UNIMPLEMENTED)
- context.set_details('Method not implemented!')
- raise NotImplementedError('Method not implemented!')
+ context.set_code(grpc.StatusCode.UNIMPLEMENTED)
+ context.set_details('Method not implemented!')
+ raise NotImplementedError('Method not implemented!')
def add_CommonServicer_to_server(servicer, server):
- rpc_method_handlers = {
- 'ExecDutCommand': grpc.unary_stream_rpc_method_handler(
- servicer.ExecDutCommand,
- request_deserializer=autotest__common__pb2.ExecDutCommandRequest.FromString,
- response_serializer=autotest__common__pb2.ExecDutCommandResponse.SerializeToString,
- ),
- 'ProvisionDut': grpc.unary_unary_rpc_method_handler(
- servicer.ProvisionDut,
- request_deserializer=autotest__common__pb2.ProvisionDutRequest.FromString,
- response_serializer=dependencies_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
- ),
- 'ProvisionLacros': grpc.unary_unary_rpc_method_handler(
- servicer.ProvisionLacros,
- request_deserializer=autotest__common__pb2.ProvisionLacrosRequest.FromString,
- response_serializer=dependencies_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
- ),
- 'FetchCrashes': grpc.unary_stream_rpc_method_handler(
- servicer.FetchCrashes,
- request_deserializer=autotest__common__pb2.FetchCrashesRequest.FromString,
- response_serializer=autotest__common__pb2.FetchCrashesResponse.SerializeToString,
- ),
- 'CreateFakeOmaha': grpc.unary_unary_rpc_method_handler(
- servicer.CreateFakeOmaha,
- request_deserializer=autotest__common__pb2.CreateFakeOmahaRequest.FromString,
- response_serializer=autotest__common__pb2.FakeOmaha.SerializeToString,
- ),
- 'DeleteFakeOmaha': grpc.unary_unary_rpc_method_handler(
- servicer.DeleteFakeOmaha,
- request_deserializer=autotest__common__pb2.DeleteFakeOmahaRequest.FromString,
- response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
- ),
- }
- generic_handler = grpc.method_handlers_generic_handler(
- 'chromiumos.config.api.test.tls.Common', rpc_method_handlers)
- server.add_generic_rpc_handlers((generic_handler,))
+ rpc_method_handlers = {
+ 'ExecDutCommand': grpc.unary_stream_rpc_method_handler(
+ servicer.ExecDutCommand,
+ request_deserializer=autotest__common__pb2.ExecDutCommandRequest.FromString,
+ response_serializer=autotest__common__pb2.ExecDutCommandResponse.SerializeToString,
+ ),
+ 'ProvisionDut': grpc.unary_unary_rpc_method_handler(
+ servicer.ProvisionDut,
+ request_deserializer=autotest__common__pb2.ProvisionDutRequest.FromString,
+ response_serializer=dependencies_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
+ ),
+ 'ProvisionLacros': grpc.unary_unary_rpc_method_handler(
+ servicer.ProvisionLacros,
+ request_deserializer=autotest__common__pb2.ProvisionLacrosRequest.FromString,
+ response_serializer=dependencies_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
+ ),
+ 'FetchCrashes': grpc.unary_stream_rpc_method_handler(
+ servicer.FetchCrashes,
+ request_deserializer=autotest__common__pb2.FetchCrashesRequest.FromString,
+ response_serializer=autotest__common__pb2.FetchCrashesResponse.SerializeToString,
+ ),
+ 'CreateFakeOmaha': grpc.unary_unary_rpc_method_handler(
+ servicer.CreateFakeOmaha,
+ request_deserializer=autotest__common__pb2.CreateFakeOmahaRequest.FromString,
+ response_serializer=autotest__common__pb2.FakeOmaha.SerializeToString,
+ ),
+ 'DeleteFakeOmaha': grpc.unary_unary_rpc_method_handler(
+ servicer.DeleteFakeOmaha,
+ request_deserializer=autotest__common__pb2.DeleteFakeOmahaRequest.FromString,
+ response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
+ ),
+ }
+ generic_handler = grpc.method_handlers_generic_handler(
+ 'chromiumos.config.api.test.tls.Common', rpc_method_handlers)
+ server.add_generic_rpc_handlers((generic_handler,))
diff --git a/server/sequence.py b/server/sequence.py
index f38bc2d1f9..b59205d894 100644
--- a/server/sequence.py
+++ b/server/sequence.py
@@ -142,7 +142,7 @@ parallel_simple(run, machines)
afe = frontend_wrappers.RetryingAFE(timeout_min=30, delay_sec=10,
user=job.user, debug=False)
# job_directores.get_job_id_or_task_id() will return a non-int opaque id
- # for Chrome OS Skylab tasks. But sequences will break in that case
+ # for ChromeOS Skylab tasks. But sequences will break in that case
# anyway, because they try to create AFE jobs internally.
current_job_id = int(
job_directories.get_job_id_or_task_id(job.resultdir))
diff --git a/server/afe_utils.py b/server/afe_utils.py
index 1c033bba54..0ce6cabf89 100644
--- a/server/afe_utils.py
+++ b/server/afe_utils.py
@@ -36,11 +36,11 @@ def _format_image_name(board, version):
def get_stable_cros_image_name_v2(host_info):
"""Retrieve the Chrome OS stable image name for a given board.
@param host_info: a host_info_store object.
- @returns Name of a Chrome OS image to be installed in order to
+ @returns Name of a ChromeOS image to be installed in order to
repair the given board.
"""
if not host_info.cros_stable_version:
@@ -36,11 +36,11 @@ def _format_image_name(board, version):
def get_stable_cros_image_name_v2(host_info):
- """Retrieve the Chrome OS stable image name for a given board.
+ """Retrieve the ChromeOS stable image name for a given board.